@@ -175,7 +175,7 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             "%s doesn't support finding elements by name." % self.driver_name
         )
 
-    def find_by_id(self, id):
+    def find_by_id(self, id):  # NOQA: A002
         """Find an element on the current page by its id.
 
         Even when only one element is find, this method returns an instance of
@@ -224,57 +224,6 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             "%s doesn't support finding elements by tag." % self.driver_name
         )
 
-    def find_link_by_href(self, href):
-        """Find all elements of a given tag in current page.
-
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
-
-        Arguments:
-            href (str): href to use in the search query.
-        """
-        raise NotImplementedError(
-            "%s doesn't support finding links by href." % self.driver_name
-        )
-
-    def find_link_by_partial_href(self, partial_href):
-        """
-        Find links by looking for a partial ``str`` in their href attribute.
-
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
-
-        Arguments:
-            partial_href (str): partial_href to use in the search query.
-        """
-        raise NotImplementedError(
-            "%s doesn't support finding links by partial href." % self.driver_name
-        )
-
-    def find_link_by_text(self, text):
-        """
-        Find links by querying for their text.
-
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
-
-        Arguments:
-            text (str): text to use in the search query.
-        """
-        raise NotImplementedError(
-            "%s doesn't support finding links by text." % self.driver_name
-        )
-
-    def find_link_by_partial_text(self, partial_text):
-        """
-        Find links by looking for a partial ``str`` in their text.
-
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
-
-        Arguments:
-            partial_text (str): partial_text to use in the search query.
-        """
-        raise NotImplementedError(
-            "%s doesn't support finding links by partial text." % self.driver_name
-        )
-
     def find_option_by_value(self, value):
         """
         Find ``<option>`` elements by their value.
@@ -316,7 +265,7 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             % self.driver_name
         )
 
-    def type(self, name, value, slowly=False):
+    def type(self, name, value, slowly=False):  # NOQA: A003
         """Type a value into an element.
 
         It's useful to test javascript events like keyPress, keyUp, keyDown, etc.
@@ -433,45 +382,7 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             % self.driver_name
         )
 
-    def click_link_by_href(self, href):
-        """Click in a link by its ``href`` attribute.
-
-        Arguments:
-            href (str): href of the element to click.
-        """
-        return self.find_link_by_href(href).first.click()
-
-    def click_link_by_partial_href(self, partial_href):
-        """Click in a link by looking for partial content of ``href`` attribute.
-
-        Arguments:
-            partial_href (str): href of the element to click.
-        """
-        return self.find_link_by_partial_href(partial_href).first.click()
-
-    def click_link_by_text(self, text):
-        """Click in a link by its text.
-
-        Arguments:
-            text (str): text of the element to click.
-        """
-        return self.find_link_by_text(text).first.click()
-
-    def click_link_by_partial_text(self, partial_text):
-        """Click in a link by partial content of its text.
-
-        Arguments:
-            partial_text (str): text of the element to click.
-        """
-        return self.find_link_by_partial_text(partial_text).first.click()
-
-    def click_link_by_id(self, id):
-        """
-        Clicks in a link by id.
-        """
-        return self.find_by_id(id).first.click()
-
-    def quit(self):
+    def quit(self):  # NOQA: A003
         """Quit the browser, closing its windows (if it has one)."""
         raise NotImplementedError("%s doesn't support quit" % self.driver_name)
 
@@ -655,7 +566,7 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             % self.driver_name
         )
 
-    def is_element_present_by_id(self, id, wait_time=None):
+    def is_element_present_by_id(self, id, wait_time=None):  # NOQA: A002
         """Verify if an element is present in the current page.
 
         Arguments:
@@ -670,7 +581,7 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             % self.driver_name
         )
 
-    def is_element_not_present_by_id(self, id, wait_time=None):
+    def is_element_not_present_by_id(self, id, wait_time=None):  # NOQA: A002
         """Verify if an element is not present in the current page.
 
         Arguments:
@@ -685,17 +596,49 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
             % self.driver_name
         )
 
-    def screenshot(self, name=None, suffix=None):
+    def screenshot(self, name=None, suffix=None, full=False, unique_file=True):
         """Take a screenshot of the current page and save it locally.
 
         Arguments:
             name (str): File name for the screenshot.
             suffix (str): File extension for the screenshot.
+            full (bool): If the screenshot should be full screen or not.
+            unique_file (bool): If true, the filename will include a path to
+                the system temp directory and extra characters at the end to
+                ensure the file is unique.
+
+        Returns:
+            str: Full file name of the created screenshot.
         """
         raise NotImplementedError(
             "%s doesn't support taking screenshots." % self.driver_name
         )
 
+    def html_snapshot(
+        self,
+        name: str = "",
+        suffix: str = ".html",
+        encoding: str = 'utf-8',
+        unique_file: bool = True,
+    ) -> str:
+        """Write the current html to a file.
+
+        Arguments:
+            name (str): File name.
+            suffix (str): File extension.
+            encoding (str): File encoding.
+            unique_file (str): If true, the filename will include a path to
+                the system temp directory and extra characters at the end to
+                ensure the file is unique.
+
+        Returns:
+            str: Full file name of the created html snapshot.
+        """
+
+        raise NotImplementedError(
+            f"{self.driver_name} doesn't support taking screenshots."
+        )
+
     @property
     def cookies(self):
         """
@@ -731,6 +674,11 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
     #: Value of the element, usually a form element
     value = property(_get_value, _set_value)
 
+    @property
+    def shadow_root(self):
+        """Get the shadow root of an element's shadow DOM."""
+        raise NotImplementedError
+
     @property
     def text(self):
         """
@@ -811,7 +759,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
         """
         raise NotImplementedError
 
-    def type(self, value, slowly=False):
+    def type(self, value, slowly=False):  # NOQA: A003
         """
         Type the ``value`` in the field.
 
@@ -839,7 +787,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
         """
         raise NotImplementedError
 
-    def screenshot(self):
+    def screenshot(self, name=None, suffix=None, full=False, unique_file=True):
         """Take screenshot of the element."""
         raise NotImplementedError
 
