@@ -4,8 +4,7 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-import six
-from six.moves.urllib import parse
+from urllib import parse
 
 from splinter.cookie_manager import CookieManagerAPI
 from splinter.request_handler.status_code import StatusCode
@@ -33,7 +32,7 @@ class CookieManager(CookieManagerAPI):
     def delete_all(self):
         self.driver.cookies.clear()
 
-    def all(self, verbose=False):
+    def all(self, verbose=False):  # NOQA: A003
         cookies = {}
         for key, value in self.driver.cookies.items():
             cookies[key] = value
@@ -64,7 +63,7 @@ class DjangoClient(LxmlDriver):
         self._custom_headers = kwargs.pop("custom_headers", {})
 
         client_kwargs = {}
-        for key, value in six.iteritems(kwargs):
+        for key, value in kwargs.items():
             if key.startswith("client_"):
                 client_kwargs[key.replace("client_", "")] = value
 
@@ -106,12 +105,18 @@ class DjangoClient(LxmlDriver):
             extra.update(self._custom_headers)
         return extra
 
-    def _do_method(self, method, url, data=None):
+    def _do_method(self, method, url, data=None, record_url=True):
         self._url = url
         extra = self._set_extra_params(url)
         func_method = getattr(self._browser, method.lower())
         self._response = func_method(url, data=data, follow=True, **extra)
-        self._last_urls.append(url)
+
+        if record_url:
+            self._last_url_index += 1
+            # Going to a new URL always crops the url history
+            self._last_urls = self._last_urls[:self._last_url_index]
+            self._last_urls.append(url)
+
         self._handle_redirect_chain()
         self._post_load()
 
