@@ -1,4 +1,7 @@
-class FindLinks(object):
+from __future__ import unicode_literals
+
+
+class FindLinks:
     """Contains methods for finding links in a parent.
 
     Accessed through the browser object or an element via the links attribute.
@@ -8,6 +11,7 @@ class FindLinks(object):
         browser.links.find_by_href('foobar')
 
     """
+
     def __init__(self, parent):
         self.parent = parent
 
