@@ -4,11 +4,8 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-try:
-    from urllib.parse import parse_qs, urlparse, urlencode, urlunparse
-except ImportError:
-    from urlparse import parse_qs, urlparse, urlunparse
-    from urllib import urlencode
+
+from urllib.parse import parse_qs, urlparse, urlencode, urlunparse
 
 from splinter.cookie_manager import CookieManagerAPI
 from splinter.request_handler.status_code import StatusCode
@@ -37,7 +34,7 @@ class CookieManager(CookieManagerAPI):
     def delete_all(self):
         self.driver.cookie_jar.clear()
 
-    def all(self, verbose=False):
+    def all(self, verbose=False):  # NOQA: A003
         cookies = {}
         for cookie in self.driver.cookie_jar:
             cookies[cookie.name] = cookie.value
@@ -85,7 +82,7 @@ class FlaskClient(LxmlDriver):
             pass
         self.status_code = StatusCode(self._response.status_code, "")
 
-    def _do_method(self, method, url, data=None):
+    def _do_method(self, method, url, data=None, record_url=True):
 
         # Set the initial URL and client/HTTP method
         self._url = url
@@ -93,7 +90,11 @@ class FlaskClient(LxmlDriver):
 
         # Continue to make requests until a non 30X response is recieved
         while True:
-            self._last_urls.append(url)
+            if record_url:
+                self._last_url_index += 1
+                # Going to a new URL always crops the url history
+                self._last_urls = self._last_urls[:self._last_url_index]
+                self._last_urls.append(url)
 
             # If we're making a GET request set the data against the URL as a
             # query.
@@ -131,7 +132,7 @@ class FlaskClient(LxmlDriver):
             # If the response was in the `30X` range get next URL to request
             url = self._response.headers["Location"]
 
-        self._url = self._last_urls[-1]
+        self._url = url
         self._post_load()
 
     def submit_data(self, form):
