@@ -4,13 +4,9 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-from selenium.webdriver import DesiredCapabilities, Firefox
+from selenium.webdriver import Firefox
 from selenium.webdriver.firefox.firefox_profile import FirefoxProfile
-from splinter.driver.webdriver import (
-    BaseWebDriver,
-    WebDriverElement as WebDriverElement,
-)
-from splinter.driver.webdriver.cookie_manager import CookieManager
+from splinter.driver.webdriver import BaseWebDriver
 from selenium.webdriver.firefox.options import Options
 
 
@@ -27,7 +23,6 @@ class WebDriver(BaseWebDriver):
         profile_preferences=None,
         fullscreen=False,
         wait_time=2,
-        timeout=90,
         capabilities=None,
         headless=False,
         incognito=False,
@@ -38,45 +33,36 @@ class WebDriver(BaseWebDriver):
         firefox_profile.set_preference("extensions.logging.enabled", False)
         firefox_profile.set_preference("network.dns.disableIPv6", False)
 
-        firefox_capabilities = DesiredCapabilities().FIREFOX
-        firefox_capabilities["marionette"] = True
-
         options = options or Options()
 
         if capabilities:
             for key, value in capabilities.items():
-                firefox_capabilities[key] = value
+                options.set_capability(key, value)
 
         if user_agent is not None:
-            firefox_profile.set_preference("general.useragent.override", user_agent)
+            options.set_preference("general.useragent.override", user_agent)
 
         if profile_preferences:
             for key, value in profile_preferences.items():
                 firefox_profile.set_preference(key, value)
 
-        if extensions:
-            for extension in extensions:
-                firefox_profile.add_extension(extension)
-
         if headless:
             options.add_argument("--headless")
 
         if incognito:
             options.add_argument("-private")
 
-        self.driver = Firefox(
+        driver = Firefox(
             firefox_profile,
-            capabilities=firefox_capabilities,
             options=options,
-            timeout=timeout,
-            **kwargs
+            **kwargs,
         )
 
+        if extensions:
+            for extension in extensions:
+                driver.install_addon(extension)
+
         if fullscreen:
-            self.driver.fullscreen_window()
+            driver.fullscreen_window()
 
-        self.element_class = WebDriverElement
-
-        self._cookie_manager = CookieManager(self.driver)
-
-        super(WebDriver, self).__init__(wait_time)
+        super(WebDriver, self).__init__(driver, wait_time)
