@@ -7,27 +7,25 @@
 from splinter.exceptions import ElementDoesNotExist
 
 
-class ElementList(object):
-    """
-    List of elements. Each member of the list is (usually) an instance
+class ElementList:
+    """Collection of elements.
+
+    Each member of the collection is by default an instance
     of :class:`ElementAPI <splinter.driver.ElementAPI>`.
 
-    Beyond the traditional list methods, the ``ElementList`` provides some
+    Beyond the traditional list methods, ``ElementList`` provides some
     other methods, listed below.
 
     There is a peculiar behavior on ElementList: you never get an
-    ``IndexError``. Instead, you can an :class:`ElementDoesNotExist
+    ``IndexError``. Instead, you get an :class:`ElementDoesNotExist
     <splinter.exceptions.ElementDoesNotExist>` exception when trying to
-    access an inexistent item in the list:
+    access a non-existent item:
 
         >>> element_list = ElementList([])
         >>> element_list[0] # raises ElementDoesNotExist
     """
 
-    def __init__(self, list, driver=None, find_by=None, query=None):
-        """
-        Creates the list.
-        """
+    def __init__(self, list, driver=None, find_by=None, query=None):  # NOQA: A002
         self._container = []
         self._container.extend(list)
 
@@ -49,8 +47,9 @@ class ElementList(object):
 
     @property
     def first(self):
-        """
-        An alias to the first element of the list:
+        """An alias to the first element of the list.
+
+        Example:
 
             >>> assert element_list[0] == element_list.first
         """
@@ -58,16 +57,19 @@ class ElementList(object):
 
     @property
     def last(self):
-        """
-        An alias to the last element of the list:
+        """An alias to the last element of the list.
+
+        Example:
 
             >>> assert element_list[-1] == element_list.last
         """
         return self[-1]
 
-    def is_empty(self):
-        """
-        Returns ``True`` if the list is empty.
+    def is_empty(self) -> bool:
+        """Check if the ElementList is empty.
+
+        Returns:
+            bool: True if the list is empty, else False
         """
         return len(self) == 0
 
@@ -91,3 +93,7 @@ class ElementList(object):
     def __len__(self):
         """__len__ checks the internal container."""
         return len(self._container)
+
+    def __repr__(self):
+        """Return the repr of the internal container."""
+        return repr(self._container)
