@@ -6,7 +6,7 @@
 
 
 class InheritedDocs(type):
-    def __new__(mcs, class_name, bases, dict):
+    def __new__(mcs, class_name, bases, dict):  # NOQA: N804, A002
         items_to_patch = [
             (k, v) for k, v in dict.items() if not k.startswith("__") and not v.__doc__
         ]
